Read

Trait Read 

pub trait Read<'de>: Sealed { }
Trait used by the deserializer for iterating over input.

This trait is sealed by default, enabling the unsealed_read_write feature removes this bound to allow objects outside of this crate to implement this trait.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a> Read<'a> for MutSliceRead<'a>

Source

impl<'a> Read<'a> for SliceRead<'a>

Available on crate features alloc or std only.
Source

impl<'a> Read<'a> for SliceReadFixed<'a, '_>

Source

impl<'de, R> Read<'de> for IoRead<R>
where R: Read,

Available on crate feature std only.