pub struct Error(/* private fields */);Expand description
This type represents all possible errors that can occur when serializing or deserializing CBOR data.
Backtrace Support
When the std feature is enabled and running on Rust 1.65+, errors automatically capture
a backtrace when created. Access it via the std::error::Error::backtrace() method.
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn is_io(&self) -> bool
pub const fn is_io(&self) -> bool
Returns true if this error was caused by a failure to read or write bytes on an IO stream.
Sourcepub const fn is_syntax(&self) -> bool
pub const fn is_syntax(&self) -> bool
Returns true if this error was caused by input that was not syntactically valid CBOR.
Sourcepub const fn is_data(&self) -> bool
pub const fn is_data(&self) -> bool
Returns true if this error was caused by data that was semantically incorrect.
Sourcepub const fn is_eof(&self) -> bool
pub const fn is_eof(&self) -> bool
Returns true if this error was caused by prematurely reaching the end of the input data.
Sourcepub const fn is_scratch_too_small(&self) -> bool
pub const fn is_scratch_too_small(&self) -> bool
Returns true if this error was caused by the scratch buffer being too small.
Note this being true implies that is_io() is also true.