Write

Trait Write 

pub trait Write: Sealed { }
A sink for serialized CBOR.

This trait is similar to the Write trait in the standard library, but has a smaller and more general API.

Any object implementing std::io::Write can be wrapped in an IoWrite that implements this trait for the underlying object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Write for Vec<u8>

Available on crate features alloc or std only.
Source

impl<W> Write for &mut W
where W: Write,

Implementors

Source

impl Write for SliceWrite<'_>

Source

impl<W: Write> Write for IoWrite<W>

Available on crate feature std only.