CBOR values, keys and serialization routines.
Enums
- Value
- The
Valueenum, a loosely typed way of representing any valid CBOR value.
Functions
- from_
value - Convert a
multi_cbor::Valueinto a typeT - to_
value - Convert a
Tintomulti_cbor::Valuewhich is an enum that can represent any valid CBOR data.