pub trait Read<'de>: Sealed { }Expand description
Trait used by the deserializer for iterating over input.
This trait is sealed by default, enabling the unsealed_read_write feature removes this bound
to allow objects outside of this crate to implement this trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".